==> gcalctool-5.5.29.tar.gz: gcalctool-5.5.29/gcalctool/lr_parser.tab.h <==
/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NEG = 258,
     tABS = 259,
     tACOS = 260,
     tACOSH = 261,
     tAND = 262,
     tANS = 263,
     tASIN = 264,
     tASINH = 265,
     tATAN = 266,
     tATANH = 267,
     tCBRT = 268,
     tCHS = 269,
     tCOS = 270,
     tCOSH = 271,
     tDDB = 272,
     tEXP = 273,
     tFRAC = 274,
     tFV = 275,
     tINT = 276,
     tLN = 277,
     tLOG10 = 278,
     tNOT = 279,
     tOR = 280,
     tPI = 281,
     tPMT = 282,
     tPV = 283,
     tRAND = 284,
     tRATE = 285,
     tSIN = 286,
     tSINH = 287,
     tSLN = 288,
     tSQRT = 289,
     tSYD = 290,
     tTAN = 291,
     tTANH = 292,
     tTERM = 293,
     tU16 = 294,
     tU32 = 295,
     tXNOR = 296,
     tXOR = 297,
     tRCL = 298,
     tSTO = 299,
     tCLR = 300,
     tINUMBER = 301,
     tDNUMBER = 302,
     POS = 303
   };
#endif
#define NEG 258
#define tABS 259
#define tACOS 260
#define tACOSH 261
#define tAND 262
#define tANS 263
#define tASIN 264
#define tASINH 265
#define tATAN 266
#define tATANH 267
#define tCBRT 268
#define tCHS 269
#define tCOS 270
#define tCOSH 271
#define tDDB 272
#define tEXP 273
#define tFRAC 274
#define tFV 275
#define tINT 276
#define tLN 277
#define tLOG10 278
#define tNOT 279
#define tOR 280
#define tPI 281
#define tPMT 282
#define tPV 283
#define tRAND 284
#define tRATE 285
#define tSIN 286
#define tSINH 287
#define tSLN 288
#define tSQRT 289
#define tSYD 290
#define tTAN 291
#define tTANH 292
#define tTERM 293
#define tU16 294
#define tU32 295
#define tXNOR 296
#define tXOR 297
#define tRCL 298
#define tSTO 299
#define tCLR 300
#define tINUMBER 301
#define tDNUMBER 302
#define POS 303




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 39 "lr_parser.y"
typedef union YYSTYPE {
  int int_t[MP_SIZE];
} YYSTYPE;
/* Line 1248 of yacc.c.  */
#line 136 "lr_parser.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE lrlval;

==> gcalctool-5.19.4.tar.gz: gcalctool-5.19.4/gcalctool/lr_parser.tab.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NEG = 258,
     tABS = 259,
     tACOS = 260,
     tACOSH = 261,
     tAND = 262,
     tANS = 263,
     tASIN = 264,
     tASINH = 265,
     tATAN = 266,
     tATANH = 267,
     tCBRT = 268,
     tCHS = 269,
     tCOS = 270,
     tCOSH = 271,
     tDDB = 272,
     tEXP = 273,
     tFRAC = 274,
     tFV = 275,
     tINT = 276,
     tLN = 277,
     tLOG10 = 278,
     tNOT = 279,
     tOR = 280,
     tPI = 281,
     tPMT = 282,
     tPV = 283,
     tRAND = 284,
     tRATE = 285,
     tSIN = 286,
     tSINH = 287,
     tSLN = 288,
     tSQRT = 289,
     tSYD = 290,
     tTAN = 291,
     tTANH = 292,
     tTERM = 293,
     tU16 = 294,
     tU32 = 295,
     tXNOR = 296,
     tXOR = 297,
     tRCL = 298,
     tSTO = 299,
     tCLR = 300,
     tINUMBER = 301,
     tDNUMBER = 302,
     POS = 303
   };
#endif
/* Tokens.  */
#define NEG 258
#define tABS 259
#define tACOS 260
#define tACOSH 261
#define tAND 262
#define tANS 263
#define tASIN 264
#define tASINH 265
#define tATAN 266
#define tATANH 267
#define tCBRT 268
#define tCHS 269
#define tCOS 270
#define tCOSH 271
#define tDDB 272
#define tEXP 273
#define tFRAC 274
#define tFV 275
#define tINT 276
#define tLN 277
#define tLOG10 278
#define tNOT 279
#define tOR 280
#define tPI 281
#define tPMT 282
#define tPV 283
#define tRAND 284
#define tRATE 285
#define tSIN 286
#define tSINH 287
#define tSLN 288
#define tSQRT 289
#define tSYD 290
#define tTAN 291
#define tTANH 292
#define tTERM 293
#define tU16 294
#define tU32 295
#define tXNOR 296
#define tXOR 297
#define tRCL 298
#define tSTO 299
#define tCLR 300
#define tINUMBER 301
#define tDNUMBER 302
#define POS 303




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 39 "./lr_parser.y"
{
  int int_t[MP_SIZE];
}
/* Line 1489 of yacc.c.  */
#line 149 "lr_parser.tab.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE lrlval;
